import icsChromelyRequest from '@icreate/ics-chromely-js-sdk';

/******************************************************************************
Copyright (c) Microsoft Corporation.

Permission to use, copy, modify, and/or distribute this software for any
purpose with or without fee is hereby granted.

THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES WITH
REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY
AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY SPECIAL, DIRECT,
INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM
LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR
OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
PERFORMANCE OF THIS SOFTWARE.
***************************************************************************** */

var __assign = function() {
    __assign = Object.assign || function __assign(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p)) t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};

var Report = /** @class */ (function () {
    function Report() {
        this.instanceId = new Date().getTime().toString();
    }
    Report.prototype.OperateEx = function (url, data, method, headers) {
        if (method === void 0) { method = 'GET'; }
        if (headers === void 0) { headers = {}; }
        // let opts =
        return icsChromelyRequest.function({
            url: "Report/".concat(url),
            method: method,
            data: __assign(__assign({}, data), { instanceId: this.instanceId }),
            headers: headers,
        });
    };
    // 清空数据源
    Report.prototype.clearData = function () {
        return this.OperateEx('ClearData');
    };
    // 注册数据源
    Report.prototype.registerData = function (name, data) {
        return this.OperateEx('RegisterData', { name: name, data: JSON.stringify(data) }, 'POST');
    };
    // 设置双面打印
    Report.prototype.doublePass = function (value) {
        return this.OperateEx('DoublePass', { value: value });
    };
    // 指定文件加载报表
    Report.prototype.load = function (fileName) {
        return this.OperateEx('Load', { fileName: fileName });
    };
    // 根据Id加载报表
    Report.prototype.loadFromId = function (reportId) {
        return this.OperateEx('LoadFromId', { reportId: reportId });
    };
    /**
     * 导出pdf
     * @param fileName 文件名称，如果不传则返回流
     * @returns 文件或者文件流
     */
    Report.prototype.ExportToPdf = function (fileName) {
        if (fileName) {
            return this.OperateEx('ExportToPdf', { fileName: fileName });
        }
        else {
            return this.OperateEx('ExportToPdfStream', null, "GET");
        }
    };
    //  导出html
    Report.prototype.exportToHtml = function (fileName) {
        return this.OperateEx('ExportToHtml', { fileName: fileName });
    };
    // 准备报表
    Report.prototype.prepare = function (append) {
        if (append === void 0) { append = false; }
        return this.OperateEx('Prepare', { append: append });
    };
    // 添加参数
    Report.prototype.addParameter = function (name, value) {
        return this.OperateEx('AddParameter', { name: name, value: value });
    };
    // 设计报表
    Report.prototype.design = function () {
        return this.OperateEx('Design');
    };
    // 预览报表
    Report.prototype.show = function () {
        return this.OperateEx('Show');
    };
    // 预览准备报表
    Report.prototype.showPrepared = function () {
        return this.OperateEx('ShowPrepared');
    };
    // 打印报表
    Report.prototype.print = function (printerName) {
        return this.OperateEx('Print', { printerName: printerName !== null && printerName !== void 0 ? printerName : '' });
    };
    // 打印准备报表
    Report.prototype.printPrepared = function (printerName) {
        return this.OperateEx('PrintPrepared', { printerName: printerName !== null && printerName !== void 0 ? printerName : '' });
    };
    // 释放报表
    Report.prototype.dispose = function () {
        return this.OperateEx('Dispose');
    };
    return Report;
}());

/*
 * @Author: 文贝
 * @Date: 2022-02-11 23:21:34
 * @LastEditors: 刘邓
 * @LastEditTime: 2022-05-10 17:11:36
 * @Descripttion:
 * @FilePath: \src\ics-chromely-plugin-report-js-sdk.ts
 */

export { Report as default };
//# sourceMappingURL=ics-chromely-plugin-report-js-sdk.es5.js.map
